@@ -5,26 +5,30 @@ use crate::settings::global_user::GlobalUser;
 use crate::settings::toml::Target;
 use crate::terminal::interactive;
 use crate::terminal::message::{Message, StdOut};
-pub fn run(target: &Target, user: &GlobalUser, id: &str) -> Result<(), failure::Error> {
-    kv::validate_target(target)?;
+
+use anyhow::Result;
+
+pub fn run(target: &Target, user: &GlobalUser, id: &str, force: bool) -> Result<()> {
     let client = http::cf_v4_client(user)?;
 
-    match interactive::confirm(&format!(
-        "Are you sure you want to delete namespace {}?",
-        id
-    )) {
-        Ok(true) => (),
-        Ok(false) => {
-            StdOut::info(&format!("Not deleting namespace {}", id));
-            return Ok(());
+    if !force {
+        match interactive::confirm(&format!(
+            "Are you sure you want to delete namespace {}?",
+            id
+        )) {
+            Ok(true) => (),
+            Ok(false) => {
+                StdOut::info(&format!("Not deleting namespace {}", id));
+                return Ok(());
+            }
+            Err(e) => anyhow::bail!(e),
         }
-        Err(e) => failure::bail!(e),
     }
 
     let msg = format!("Deleting namespace {}", id);
     StdOut::working(&msg);
 
-    let response = delete(client, target, id);
+    let response = delete(client, target.account_id.load()?, id);
     match response {
         Ok(_) => {
             StdOut::success("Success");
